==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp.md <==
# AwsTransferFamilyAwsFtp


```text
aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp
```

```text
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')
```



| Illustration | AwsTransferFamilyAwsFtp | AwsTransferFamilyAwsFtpCard | AwsTransferFamilyAwsFtpGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp.png) | ![illustration for AwsTransferFamilyAwsFtp](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp.Local.png) | ![illustration for AwsTransferFamilyAwsFtpCard](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtpCard.Local.png) | ![illustration for AwsTransferFamilyAwsFtpGroup](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtpGroup.Local.png) |




## AwsTransferFamilyAwsFtp

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtp
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtp('AwsTransferFamilyAwsFtp', 'Aws Transfer Family Aws Ftp', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtp
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtp('AwsTransferFamilyAwsFtp', 'Aws Transfer Family Aws Ftp', 'an optional tech label')
@enduml
```

## AwsTransferFamilyAwsFtpCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpCard
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtpCard('AwsTransferFamilyAwsFtpCard', 'Aws Transfer Family Aws Ftp Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpCard
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtpCard('AwsTransferFamilyAwsFtpCard', 'Aws Transfer Family Aws Ftp Card', 'an optional description')
@enduml
```

## AwsTransferFamilyAwsFtpGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpGroup
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtpGroup('AwsTransferFamilyAwsFtpGroup', 'Aws Transfer Family Aws Ftp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpGroup
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtpGroup('AwsTransferFamilyAwsFtpGroup', 'Aws Transfer Family Aws Ftp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp.md <==
# AwsTransferFamilyAwsFtp


```text
aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp
```

```text
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')
```



| Illustration | AwsTransferFamilyAwsFtp | AwsTransferFamilyAwsFtpCard | AwsTransferFamilyAwsFtpGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp.png) | ![illustration for AwsTransferFamilyAwsFtp](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp.Local.png) | ![illustration for AwsTransferFamilyAwsFtpCard](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtpCard.Local.png) | ![illustration for AwsTransferFamilyAwsFtpGroup](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtpGroup.Local.png) |




## AwsTransferFamilyAwsFtp

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtp
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtp('AwsTransferFamilyAwsFtp', 'Aws Transfer Family Aws Ftp', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtp
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtp('AwsTransferFamilyAwsFtp', 'Aws Transfer Family Aws Ftp', 'an optional tech label')
@enduml
```

## AwsTransferFamilyAwsFtpCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpCard
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtpCard('AwsTransferFamilyAwsFtpCard', 'Aws Transfer Family Aws Ftp Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpCard
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtpCard('AwsTransferFamilyAwsFtpCard', 'Aws Transfer Family Aws Ftp Card', 'an optional description')
@enduml
```

## AwsTransferFamilyAwsFtpGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpGroup
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtpGroup('AwsTransferFamilyAwsFtpGroup', 'Aws Transfer Family Aws Ftp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpGroup
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtp')

' renders the element
AwsTransferFamilyAwsFtpGroup('AwsTransferFamilyAwsFtpGroup', 'Aws Transfer Family Aws Ftp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
